summaryrefslogtreecommitdiff
path: root/src/gui/npc.h
diff options
context:
space:
mode:
authorBjörn Steinbrink <B.Steinbrink@gmx.de>2005-09-13 22:56:29 +0000
committerBjörn Steinbrink <B.Steinbrink@gmx.de>2005-09-13 22:56:29 +0000
commit3dc311a652d1fda1252903a974920395e56e5668 (patch)
tree7098d55015d28a4d973c5073d7c9e45ae03ec400 /src/gui/npc.h
parent78771718bf7af14273d7bb0090dccff97b00b397 (diff)
downloadmana-client-3dc311a652d1fda1252903a974920395e56e5668.tar.gz
mana-client-3dc311a652d1fda1252903a974920395e56e5668.tar.bz2
mana-client-3dc311a652d1fda1252903a974920395e56e5668.tar.xz
mana-client-3dc311a652d1fda1252903a974920395e56e5668.zip
Merged with SDL_NET_TEST branch.
Diffstat (limited to 'src/gui/npc.h')
-rw-r--r--src/gui/npc.h17
1 files changed, 11 insertions, 6 deletions
diff --git a/src/gui/npc.h b/src/gui/npc.h
index 336bad62..e9960cd2 100644
--- a/src/gui/npc.h
+++ b/src/gui/npc.h
@@ -58,29 +58,34 @@ class NpcListDialog : public Window, public gcn::ActionListener,
/**
* Called when receiving actions from the widgets.
*/
- void action(const std::string& eventId);
+ void
+ action(const std::string& eventId);
/**
* Returns the number of items in the choices list.
*/
- int getNumberOfElements();
+ int
+ getNumberOfElements();
/**
* Returns the name of item number i of the choices list.
*/
- std::string getElementAt(int i);
+ std::string
+ getElementAt(int i);
/**
* Fills the options list for an NPC dialog.
*
* @param string A string with the options separated with colons.
*/
- void parseItems(const char *string, unsigned short len);
+ void
+ parseItems(const std::string &itemString);
/**
* Resets the list by removing all items.
*/
- void reset();
+ void
+ reset();
private:
gcn::Button *okButton;
@@ -58,29 +58,34 @@ class NpcListDialog : public Window, public gcn::ActionListener,
* Fills the options list for an NPC dialog.
*
- * @param string A string with the options separated with colons.
+ * @param itemString A string with the options separated with colons.
*/